@@ -23,9 +23,11 @@
 
 #include <gtkmm.h>
 #include <libvtemm/charattributes.h>
+#include <libvtemm/cursorposition.h>
 #include <libvtemm/init.h>
-#include <libvtemm/pty.h>
-#include <libvtemm/reaper.h>
+#include <libvtemm/match.h>
+#include <libvtemm/padding.h>
+#include <libvtemm/shared.h>
 #include <libvtemm/terminal.h>
 #include <libvtemm/terminalaccessible.h>
 #include <libvtemm/textandcharattrs.h>
